@@ -49,7 +49,16 @@ class High_Level:
 		access_key = get_access_key(email, password)
 		return await self._parent.low_level.login(access_key)
 
-	async def get_keystore(self, key: bytes) -> Union[Dict[str, Any], NovelAIError]:
+	async def get_keystore(self, key: bytes) -> Union[Dict[str, Dict[str, bytes]], NovelAIError]:
+		"""
+		Retrieve the keystore and decrypt it in a readable manner.
+		The keystore is the mapping of meta -> encryption key of each object.
+
+		:param key: Account encryption key
+		
+		:return: Keystore in the form { "keys": { "<meta>": <key> } }
+		"""
+
 		keystore = await self._parent.low_level.get_keystore()
 
 		# TODO: add enum for error
@@ -106,6 +115,21 @@ class High_Level:
 
 		return json_data
 
+	async def set_keystore(self, keystore: Dict[str, Dict[str, bytes]], key: bytes):
+		assert type(keystore) is dict, f"Expected type 'dict' for keystore, but got '{type(keystore)}'"
+
+		keys = keystore["keys"]
+		assert type(keys) is dict, f"Expected type 'dict' for keystore, but got '{type(keys)}'"
+
+		for key in keys:
+			assert type(key) is str, f"Expected type 'str' for a key of the keystore, but got '{type(key)}'"
+			assert type(keys[key]) is bytes, f"Expected type 'bytes' for an item of the keystore, but got '{type(keys[key])}'"
+
+			keys[key] = list(keys[key])
+
+#		json_data = json.dumps(keystore)
+#		encrypted_data, nonce = encrypt()
+
 	async def download_stories(self) -> Union[Dict[str, List[Dict[str, Union[str, int]]]], NovelAIError]:
 		stories = await self._parent.low_level.download_objects("stories")
 
